@@ -3,7 +3,7 @@ test_that("You can bind skim_df rows", {
   skimmed2 <- skim(mtcars)
   combined <- vctrs::vec_rbind(skimmed1, skimmed2)
   expect_s3_class(combined, "skim_df")
-  
+
   attrs <- attributes(combined)
   expect_equal(attrs$data_rows, 182)
   expect_equal(attrs$data_cols, 16)
@@ -19,7 +19,7 @@ test_that("You can bind skim_df rows", {
 
 test_that("When binding columns, fall back to tbl_df", {
   skimmed <- skim(iris)
-  combined <- vctrs::vec_cbind(skimmed, skimmed)
+  combined <- vctrs::vec_cbind(skimmed, skimmed, .name_repair = "universal_quiet")
   expect_s3_class(combined, "tbl")
   expect_false("skim_df" %in% class(combined))
 })
